@@ -94,7 +94,7 @@ class BaseEntity(object):
                 res = str(v).strip() if v else ''
         elif t == DateTimeField:
             if v:
-                if isinstance(v, datetime):
+                if isinstance(v, (date, datetime)):
                     res = v
                 else:
                     res = dateutil.parser.parse(v)
@@ -138,7 +138,7 @@ class ElasticEntity(BaseEntity):
         return '_doc'
 
     @classmethod
-    def get(cls, _id=None, _count=10, _offset=0, _sort=[], _process=True, _source=None, _exclude=[], _all=False, _random=False, **kwargs):
+    def get(cls, _id=None, _count=10, _offset=0, _sort=[], _process=True, _source=None, _exclude=[], _all=False, _random=False, _range=None, **kwargs):
         if _id:
             resp = current_app.es.get(index=cls._table(), id=_id, ignore=[400, 404])
             logger.debug(u'GET: {0}'.format(resp))
@@ -153,6 +153,10 @@ class ElasticEntity(BaseEntity):
                 return k if isinstance(v, bool) else '{0}.keyword'.format(k)
             must = [{"terms" if isinstance(v, list) else "term": {pre_field(k, v): v}} for k, v in six.iteritems(kwargs)]
 
+            if _range:
+                _f, _s, _e = _range
+                must.append({"range": {_f: {"gte": _s, "lte": _e}}})
+
             qbool = {
                 "must": must
             }
@@ -337,7 +341,8 @@ class Page(ElasticEntity):
         'is_new': bool,
         'is_featured': bool,
         'is_sponsored': bool,
-        'onwer': str,
+        'owner': str,
+        'status': str, # status approve: draft, in review, published (manager editor mode)
         'is_draft': bool,
         'is_sandbox': bool,
         'user_rating': float,
@@ -393,6 +398,7 @@ class Page(ElasticEntity):
         'welcome_package_min_dep': int,
         'no_deposit_fs': int,
         'no_deposit_note': str,
+        'cashback': int,
         'promotions': list,
         'geo_blacklist': str,
         'geo_whitelist': str,
@@ -967,6 +973,7 @@ class Actor(ElasticEntity, Guest):
         'last_auth': DateTimeField,
         'actor_is_active': bool,
         'actor_is_admin': bool,
+        'zones': list,
         'ip': str,
         'ua': str,
         'cid': str,
